define(
//begin v1.x content
({
	insertTableTitle: "Inserir tabela",
	modifyTableTitle: "Modificar tabela",
	rows: "Linhas:",
	columns: "Colunas:",
	align: "Alinhar:",
	cellPadding: "Preenchimento de células:",
	cellSpacing: "Espaçamento de células:",
	tableWidth: "Largura da tabela:",
	backgroundColor: "Cor de segundo plano:",
	borderColor: "Cor do contorno:",
	borderThickness: "Espessura do contorno",
	percent: "percentagem",
	pixels: "píxeis",
	"default": "predefinição",
	left: "esquerda",
	center: "centro",
	right: "direita",
	buttonSet: "Definir", // translated elsewhere?
	buttonInsert: "Inserir",
	buttonCancel: "Cancelar",

	selectTableLabel: "Seleccionar tabela",
	insertTableRowBeforeLabel: "Adicionar linha antes",
	insertTableRowAfterLabel: "Adicionar linha depois",
	insertTableColumnBeforeLabel: "Adicionar coluna antes",
	insertTableColumnAfterLabel: "Adicionar coluna depois",
	deleteTableRowLabel: "Eliminar linha",
	deleteTableColumnLabel: "Eliminar coluna"
})
//end v1.x content
);
